summaryrefslogtreecommitdiffstats
path: root/chromium/third_party/skia/include/core/SkWeakRefCnt.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/skia/include/core/SkWeakRefCnt.h')
-rw-r--r--chromium/third_party/skia/include/core/SkWeakRefCnt.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chromium/third_party/skia/include/core/SkWeakRefCnt.h b/chromium/third_party/skia/include/core/SkWeakRefCnt.h
index e2a7308443b..210dcc9f1c7 100644
--- a/chromium/third_party/skia/include/core/SkWeakRefCnt.h
+++ b/chromium/third_party/skia/include/core/SkWeakRefCnt.h
@@ -89,9 +89,9 @@ public:
*/
bool SK_WARN_UNUSED_RESULT try_ref() const {
if (sk_atomic_conditional_inc(&fRefCnt) != 0) {
// Aquire barrier (L/SL), if not provided above.
// Prevents subsequent code from happening before the increment.
- sk_membar_aquire__after_atomic_conditional_inc();
+ sk_membar_acquire__after_atomic_conditional_inc();
return true;
}
return false;
@@ -115,9 +115,9 @@ public:
SkASSERT(fWeakCnt > 0);
// Release barrier (SL/S), if not provided below.
if (sk_atomic_dec(&fWeakCnt) == 1) {
// Aquire barrier (L/SL), if not provided above.
// Prevents code in destructor from happening before the decrement.
- sk_membar_aquire__after_atomic_dec();
+ sk_membar_acquire__after_atomic_dec();
#ifdef SK_DEBUG
// so our destructor won't complain
fWeakCnt = 1;
@@ -89,9 +89,9 @@ public:
bool SK_WARN_UNUSED_RESULT try_ref() const {
if (sk_atomic_conditional_inc(&fRefCnt) != 0) {
- // Aquire barrier (L/SL), if not provided above.
+ // Acquire barrier (L/SL), if not provided above.
// Prevents subsequent code from happening before the increment.
@@ -115,9 +115,9 @@ public:
// Release barrier (SL/S), if not provided below.
if (sk_atomic_dec(&fWeakCnt) == 1) {
- // Aquire barrier (L/SL), if not provided above.
+ // Acquire barrier (L/SL), if not provided above.
// Prevents code in destructor from happening before the decrement.